/*
  Generates 12x12bit 1465Hz "sine wave" on Arduino Due PORTC pins.
  Formula for PicoScope MSO math channel DAC:

  LowPass((2048*D11+1024*D10+512*D9+256*D8+128*D7+64*D6+32*D5+16*D4+8*D3+4*D2+2*D1+1*D0)/4096/0.9998,175000)-0.5

  By HrHunt @ PicoTech forum
  E-mail: info@lab.fyi
  Thread: https://www.picotech.com/support/topic27831.html

  33 C1 D0
  34 C2 D1
  35 C3 D2
  36 C4 D3
  37 C5 D4
  38 C6 D5
  39 C7 D6
  40 C8 D7

  51 C12 D8
  50 C13 D9
  49 C14 D10
  48 C15 D11

  47 C16 A? for analog trigger if needed
*/

const int iPoints = 4096;
unsigned int aiWave[iPoints];

void setup()
{
  REG_PIOC_OWER = 0xFFFFFFFF;
  REG_PIOC_OER = 0xFFFFFFFF;

  float fPhaseStep = 2 * PI / iPoints;
  float fPhase = -PI;
  float fY;
  unsigned int i;
  unsigned int x, x1, x2;

  for (i = 0; i < iPoints; i++)
  {
    fY = sin(fPhase);
    fY = (fY + 0.99999994) * (iPoints / 2);
    x = (int) fY;
    x1 = x & 0x000000FF;
    x1 = x1 << 1;
    x2 = x & 0x00000F00;
    x2 = x2 << 4; 
    x = x1 | x2;
    if (i == 0) x = x + 0x10000; // @ 47 C16 A? for analog trigger if needed
    aiWave[i] = x;
    fPhase += fPhaseStep;
  }
}

void loop()
{
  unsigned int i;
  while(true)
    for (i = 0; i < iPoints; i++)
      REG_PIOC_ODSR = aiWave[i];
}
